@@ -75,6 +75,8 @@
 #define AFT_ISDN_BRI_SHARK_SUBSYS_VENDOR	0xA500	/* AFT-ISDN BRI SHARK board */
 #define AFT_56K_SHARK_SUBSYS_VENDOR		0xA056	/* AFT-56K SHARK board */
 
+#define AFT_A600_SUBSYS_VENDOR			0xA600	/* AFT-600 Series board */
+
 #define AFT_2SERIAL_V35X21_SUBSYS_VENDOR	0xA031	/* AFT-A142 2 Port V.35/X.21 board */
 #define AFT_4SERIAL_V35X21_SUBSYS_VENDOR	0xA032	/* AFT-A144 4 Port V.35/X.21 board */
 #define AFT_2SERIAL_RS232_SUBSYS_VENDOR		0xA033	/* AFT-A142 2 Port RS232 board */
@@ -104,6 +106,7 @@
 #define AFT_CHIP_OLD_X300	0x0300
 #define AFT_CHIP_OLD_X400	0x0400
 #define AFT_CHIP_X200		0x0020
+#define AFT_CHIP_X250		0x0025
 #define AFT_CHIP_X300		0x0030
 #define AFT_CHIP_X400		0x0040
 #define AFT_CHIP_X1000		0x0100
